summaryrefslogtreecommitdiff
path: root/src/chain.cc
diff options
context:
space:
mode:
Diffstat (limited to 'src/chain.cc')
-rw-r--r--src/chain.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/chain.cc b/src/chain.cc
index 228c3fec..67f2c8d5 100644
--- a/src/chain.cc
+++ b/src/chain.cc
@@ -202,8 +202,8 @@ post_handler_ptr chain_post_handlers(post_handler_ptr base_handler,
// period_posts is like subtotal_posts, but it subtotals according to time
// periods rather than totalling everything.
//
// dow_posts is like period_posts, except that it reports all the posts
// that fall on each subsequent day of the week.
if (report.HANDLED(equity))
handler.reset(new posts_as_equity(handler, expr));
else if (report.HANDLED(subtotal))
@@ -211,7 +211,7 @@ post_handler_ptr chain_post_handlers(post_handler_ptr base_handler,
}
if (report.HANDLED(dow))
- handler.reset(new dow_posts(handler, expr));
+ handler.reset(new day_of_week_posts(handler, expr));
else if (report.HANDLED(by_payee))
handler.reset(new by_payee_posts(handler, expr));
@@ -202,8 +202,8 @@ post_handler_ptr chain_post_handlers(post_handler_ptr base_handler,
// periods rather than totalling everything.
//
- // dow_posts is like period_posts, except that it reports all the posts
- // that fall on each subsequent day of the week.
+ // day_of_week_posts is like period_posts, except that it reports
+ // all the posts that fall on each subsequent day of the week.
if (report.HANDLED(equity))
handler.reset(new posts_as_equity(handler, expr));